@@ -32,8 +32,12 @@
 #include <libnotify/notify.h>
 
 #ifdef WITH_APPINDICATOR
+#if USE_AYATANA_INDICATORS
+#include <libayatana-appindicator/app-indicator.h>
+#else
 #include <libappindicator/app-indicator.h>
 #endif
+#endif
 
 #include <NetworkManager.h>
 
