@@ -291,15 +291,12 @@ populate_ui (CEPageEthernet *self)
 }
 
 static void
-finish_setup (CEPageEthernet *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageEthernet *self, gpointer user_data)
 {
 	CEPage *parent = CE_PAGE (self);
 	CEPageEthernetPrivate *priv = CE_PAGE_ETHERNET_GET_PRIVATE (self);
 	GtkWidget *widget;
 
-	if (error)
-		return;
-
 	populate_ui (self);
 
 	g_signal_connect (priv->linkneg, "changed", G_CALLBACK (link_special_changed_cb), self);
@@ -370,7 +367,7 @@ ce_page_ethernet_new (NMConnectionEditor *editor,
 		nm_connection_add_setting (connection, NM_SETTING (priv->setting));
 	}
 
-	g_signal_connect (self, "initialized", G_CALLBACK (finish_setup), NULL);
+	g_signal_connect (self, CE_PAGE_INITIALIZED, G_CALLBACK (finish_setup), NULL);
 
 	return CE_PAGE (self);
 }
