@@ -114,13 +114,10 @@ populate_ui (CEPageInfiniband *self)
 }
 
 static void
-finish_setup (CEPageInfiniband *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageInfiniband *self, gpointer user_data)
 {
 	CEPageInfinibandPrivate *priv = CE_PAGE_INFINIBAND_GET_PRIVATE (self);
 
-	if (error)
-		return;
-
 	populate_ui (self);
 
 	g_signal_connect (priv->transport_mode, "changed", G_CALLBACK (stuff_changed), self);
@@ -161,7 +158,7 @@ ce_page_infiniband_new (NMConnectionEditor *editor,
 		nm_connection_add_setting (connection, NM_SETTING (priv->setting));
 	}
 
-	g_signal_connect (self, "initialized", G_CALLBACK (finish_setup), NULL);
+	g_signal_connect (self, CE_PAGE_INITIALIZED, G_CALLBACK (finish_setup), NULL);
 
 	return CE_PAGE (self);
 }
