@@ -623,11 +623,8 @@ populate_ui (CEPageTeamPort *self)
 }
 
 static void
-finish_setup (CEPageTeamPort *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageTeamPort *self, gpointer user_data)
 {
-	if (error)
-		return;
-
 	populate_ui (self);
 }
 
@@ -667,7 +664,7 @@ ce_page_team_port_new (NMConnectionEditor *editor,
 		nm_connection_add_setting (connection, NM_SETTING (priv->setting));
 	}
 
-	g_signal_connect (self, "initialized", G_CALLBACK (finish_setup), NULL);
+	g_signal_connect (self, CE_PAGE_INITIALIZED, G_CALLBACK (finish_setup), NULL);
 
 	return CE_PAGE (self);
 }
