@@ -23,19 +23,11 @@
 #ifndef WS_WPA_EAP_H
 #define WS_WPA_EAP_H
 
-#if defined (LIBNM_BUILD)
-#include <NetworkManager.h>
-#elif defined (LIBNM_GLIB_BUILD)
-#include <nm-connection.h>
-#else
-#error neither LIBNM_BUILD nor LIBNM_GLIB_BUILD defined
-#endif
-
 typedef struct _WirelessSecurityWPAEAP WirelessSecurityWPAEAP;
 
 WirelessSecurityWPAEAP * ws_wpa_eap_new (NMConnection *connection,
                                          gboolean is_editor,
-                                         gboolean secrets_only);
+                                         gboolean secrets_only,
+                                         const char *const*secrets_hints);
 
 #endif /* WS_WPA_EAP_H */
-
